@@ -3,9 +3,9 @@ from typing import Any, Dict, List, Optional, Sequence, Set
 from dagster import (
     Field,
     InputDefinition,
+    OpDefinition,
+    OpExecutionContext,
     OutputDefinition,
-    SolidDefinition,
-    SolidExecutionContext,
 )
 from dagster.core.definitions.events import Output
 
@@ -18,22 +18,20 @@ class BaseComponent:
     tags: Dict[str, str] = {}
 
     @classmethod
-    def _compute_hook(cls, step_context: SolidExecutionContext, inputs: Dict[str, Any]):
+    def _compute_hook(cls, step_context: OpExecutionContext, inputs: Dict[str, Any]):
         """The compute hook that runs the actual compute function.
             Needs to overridden by the descendant classes.
 
         Args:
-            step_context (SolidExecutionContext): The Dagster execution context.
-            inputs (Dict[str, Any]): The inputs that are supplied to the solid as a dictionary.
+            step_context (OpExecutionContext): The Dagster execution context.
+            inputs (Dict[str, Any]): The inputs that are supplied to the op as a dictionary.
 
         Raises:
             NotImplementedError: The compute hook is not implemented by default.
         """
         # Run the compute function ("cls.compute_function" needs to be defined by the children)
-        # The inputs of the previous and solid config are injected into the compute function
-        results = getattr(cls, cls.compute_function)(
-            **inputs, **step_context.solid_config
-        )
+        # The inputs of the previous and op config are injected into the compute function
+        results = getattr(cls, cls.compute_function)(**inputs, **step_context.op_config)
 
         # If the results are not a sequence, wrap it in a list
         if not isinstance(results, Sequence):
@@ -44,18 +42,18 @@ class BaseComponent:
             yield Output(result, output_def.name)
 
     @classmethod
-    def to_solid(cls, name: str, description: Optional[str] = None) -> SolidDefinition:
-        """Generates a solid definition for this component.
+    def to_op(cls, name: str, description: Optional[str] = None) -> OpDefinition:
+        """Generates a op definition for this component.
 
         Args:
-            name (str): The name of the solid.
+            name (str): The name of the op.
             input_defs (List[InputDefinition], optional): The list of Dagster input values. Defaults to [].
             output_defs (List[OutputDefinition], optional): The list of Dagster output values. Defaults to [].
 
         Returns:
-            SolidDefinition: The Solid that is used by Dagster to execute this component .
+            OpDefinition: The operator that is used by Dagster to execute this component.
         """
-        return SolidDefinition(
+        return OpDefinition(
             name=name,
             description=description,
             input_defs=cls.input_defs,
