@@ -23,6 +23,11 @@ class NounPhraseTransformer(BaseTransformer):
             default_value="nl_core_news_lg",
             description="The name of the spacy language model (nl_core_news_lg)",
         ),
+        "keep_tokens": Field(
+            bool,
+            default_value=False,
+            description="Whether to keep all tokens, or only noun phrases",
+        ),
     }
 
     @classmethod
